from setuptools import setup

setup(name='jm-networking',
      version='1.0.1',
      description="A basic networking layer with async callbacks",
      url="https://github.com/miller46/jm-networking",
      license='MIT'
      )
